@@ -19,11 +19,16 @@
 # THE SOFTWARE.
 
 import re
+import sys
 import types
 import collections
 
-from six import string_types, text_type, iterkeys, iteritems
-from six.moves import zip
+if sys.version_info[0] == 3:
+    string_types = (str,)
+    iteritems = lambda x: x.items()
+else:
+    string_types = (basestring,)
+    iteritems = lambda x: x.iteritems()
 
 __all__ = ['Row', 'Regex', 'Prototype', 'adapt']
 
@@ -238,7 +243,7 @@ class Regex(BaseValidator):
         return self
 
     def validate(self, session, data):
-        if not isinstance(data, text_type):
+        if not isinstance(data, string_types):
             raise session.type_error(got=clsname(data), expected='string')
 
         # Apply the regular expression and expect a match
